package com.yihu.hos.standard.controller;

import com.yihu.hos.config.JsonDateValueProcessor;
import com.yihu.hos.core.constants.MicroServices;
import com.yihu.hos.standard.model.standard.*;
import com.yihu.hos.standard.service.standard.*;
import com.yihu.hos.web.framework.model.standard.StandardVersion;
import com.yihu.hos.web.framework.util.controller.BaseController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import net.sf.json.JSONArray;
import net.sf.json.JsonConfig;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.io.IOException;
import java.text.ParseException;
import java.util.Date;
import java.util.List;


@RestController("StdCenterEndPoint")
@RequestMapping(value = MicroServices.ApiVersion.Version1_0+"/standardCenter")
@Api(description = "获取标准列表相关接口")
public class StdCenterEndPoint extends BaseController {

    @Autowired
    private STDVersionService stdVersionService;
    @Autowired
    private StdDatasetService stdDatasetService;
    @Autowired
    private StdMetadataService stdMetadataService;
    @Autowired
    private StdDictService stdDictService;
    @Autowired
    private StdDictEntryService stdDictEntryService;
    @Autowired
    private StdIndexService stdIndexService;
    @Autowired
    private StdRelationService stdRelationService;
    @Autowired
    private StandardService standardService;


    @RequestMapping("/stdInfo/list")
    @ApiOperation(value = "获取版本列表",  produces = "application/json", notes = "获取版本列表")
    public String getStdInfo(@ApiParam(name = "filters", value = "过滤器，为空检索所有条件", defaultValue = "")
                              @RequestParam(value = "filters", required = false) String filters) throws ParseException {
        List<StandardModel> list = standardService.search(null, filters, null, null, null);
        JSONArray json = JSONArray.fromObject(list);
        return json.toString();
    }


    @RequestMapping("/version/list")
    @ApiOperation(value = "获取版本号列表",  produces = "application/json", notes = "获取版本号列表")
    public String getVersions(@ApiParam(name = "filters", value = "过滤器，为空检索所有条件", defaultValue = "")
                                 @RequestParam(value = "filters", required = false) String filters) throws ParseException {
        List versions = stdVersionService.search(null, filters, null, null, null);
        JsonConfig config = new JsonConfig();
        config.registerJsonValueProcessor(Date.class, new JsonDateValueProcessor());
        JSONArray json = JSONArray.fromObject(versions, config);
        return json.toString();
    }

    @RequestMapping("/dataset/list")
    @ApiOperation(value = "获取数据集列表",  produces = "application/json", notes = "获取数据集列表")
    public String getDatasetList(@ApiParam(name = "filters", value = "过滤器，为空检索所有条件", defaultValue = "")
                             @RequestParam(value = "filters", required = false) String filters,
                             @ApiParam(name = "version", value = "版本", defaultValue = "")
                             @RequestParam(value = "version") String version) throws IOException {
        List<StdDataSetModel> list = stdDatasetService.searchPage(StdDataSetModel.class, StandardVersion.DataSetTable,version, filters, null, null, null,true);
        JSONArray json = JSONArray.fromObject(list);
        return json.toString();
    }

    @RequestMapping("/metadata/list")
    @ApiOperation(value = "获取数据元列表",  produces = "application/json", notes = "获取数据元列表")
    public String getMetadataList(@ApiParam(name = "filters", value = "过滤器，为空检索所有条件", defaultValue = "")
                          @RequestParam(value = "filters", required = false) String filters,
                          @ApiParam(name = "version", value = "版本", defaultValue = "")
                          @RequestParam(value = "version") String version) throws IOException {
        List<StdMetaDataModel> list = stdMetadataService.searchPage(StdMetaDataModel.class, StandardVersion.MetaDataTable,version, filters, null, null, null,true);
        JSONArray json = JSONArray.fromObject(list);
        return json.toString();
    }

    @RequestMapping("/dict/list")
    @ApiOperation(value = "获取标准字典列表",  produces = "application/json", notes = "获取标准字典列表")
    public String getDictList(@ApiParam(name = "filters", value = "过滤器，为空检索所有条件", defaultValue = "")
                                  @RequestParam(value = "filters", required = false) String filters,
                                  @ApiParam(name = "version", value = "版本", defaultValue = "")
                                  @RequestParam(value = "version") String version) throws IOException {
        List<StdDictionaryModel> list = stdDictService.searchPage(StdDictionaryModel.class, StandardVersion.DictTable,version, filters, null, null, null,true);
        JsonConfig config = new JsonConfig();
        config.registerJsonValueProcessor(Date.class, new JsonDateValueProcessor());
        JSONArray json = JSONArray.fromObject(list, config);
        return json.toString();
    }

    @RequestMapping("/dictItem/list")
    @ApiOperation(value = "获取标准字典项列表",  produces = "application/json", notes = "获取标准字典项列表")
    public String getDictItemList(@ApiParam(name = "filters", value = "过滤器，为空检索所有条件", defaultValue = "")
                                  @RequestParam(value = "filters", required = false) String filters,
                                  @ApiParam(name = "version", value = "版本", defaultValue = "")
                                  @RequestParam(value = "version") String version) throws IOException {
        List<StdDictionaryEntryModel> list = stdDictEntryService.searchPage(StdDictionaryEntryModel.class, StandardVersion.DictEntryTable,version, filters, null, null, null,true);
        JSONArray json = JSONArray.fromObject(list);
        return json.toString();
    }

    @RequestMapping("/datasetIndex/list")
    @ApiOperation(value = "获取标准索引列表",  produces = "application/json", notes = "获取标准索引列表")
    public String getDatasetIndexList(@ApiParam(name = "filters", value = "过滤器，为空检索所有条件", defaultValue = "")
                                  @RequestParam(value = "filters", required = false) String filters,
                                  @ApiParam(name = "version", value = "版本", defaultValue = "")
                                  @RequestParam(value = "version") String version) throws IOException {
        List<StdIndex> list = stdIndexService.searchPage(StdIndex.class, StandardVersion.StdIndexTable,version, filters, null, null, null,true);
        JSONArray json = JSONArray.fromObject(list);
        return json.toString();
    }

    @RequestMapping("/relation/list")
    @ApiOperation(value = "获取版本号列表",  produces = "application/json", notes = "获取版本号列表")
    public String getRelation(@ApiParam(name = "version", value = "版本", defaultValue = "")
                              @RequestParam(value = "version") String version,
                              @ApiParam(name = "filters", value = "过滤器，为空检索所有条件", defaultValue = "")
                              @RequestParam(value = "filters", required = false) String filters) throws IOException {
        List<StdDatasetRelation> list = stdRelationService.searchPage(StdDatasetRelation.class, StandardVersion.StdRelationTable,version, filters, null, null, null,true);
        JSONArray json = JSONArray.fromObject(list);
        return json.toString();
    }
}
